' This Visual Basic script provides an example that demonstrates integration of
' ITSRM and ITSM.  This script is intended to be run in response to an alert 
' generated by ITSRM's constraint processing.  Files that violate the constraint
' definition will be archived to ITSM and then deleted.
'
' This script is an example that may need to be modified for your environment.
' For example, please ensure the setting of ITSM environmental variables
' match your ITSM installation location.
'
' This script can be run on a Windows machines.
' The ITSRM UI specifies the script name to be run in response to an alert 
' associated with a constraint violation.   The script name specified should include 
' the .vbs qualifier (i.e. tsm_arch_del.vbs). 
' 
' Dependencies:  
'    Windows:
'       This script is dependent on WSH Version 5.6 (or later).
'       The latest version of WSH can be downloaded from http://msdn.microsoft.com/scripting.
'       You can run the script wshlvl.vbs to determine the level of WSH installed on a Windows machine.
'       The script wshlvl.vbs is provided in the ITSRM scripts subdirectory.
'    ITSM:
'       The ITSM client option passwordaccess generate must be specified.
'       This script uses the -filelist option with the ITSM archive command and therefore the
'       ITSM client must be at 4.2 or above.


' The following define the ITSM environment variables and should be set based on
' installation location of the ITSM client. 
const dsm_dir = "C:\Program Files\Tivoli\TSM\baclient"
const dsm_config = "C:\Program Files\Tivoli\TSM\baclient\dsm.opt"
const dsm_log = "C:\Program Files\Tivoli\TSM\baclient"


' Save script input parameters to local variables.
computername = WScript.Arguments.Item(0)
mountpoint = WScript.Arguments.Item(1)
size = WScript.Arguments.Item(2)
threshold = WScript.Arguments.Item(3)
cappct = WScript.Arguments.Item(4)
filecount = WScript.Arguments.Item(5)
filelist = WScript.Arguments.Item(9)
Set fso = CreateObject("Scripting.FileSystemObject")

' The following statements print the input parameters and can be uncommented for information
' and debugging purposes.
' wscript.echo ("computername = " & computername)
' wscript.echo ("mountpoint = " & mountpoint)
' wscript.echo ("size = " & size)
' wscript.echo ("threshold = " & threshold)
' wscript.echo ("cappct = " & cappct)
' wscript.echo ("filecount = " & filecount)
' Set InputFile = fso.OpenTextFile(filelist, 1)
' do while not InputFile.AtEndOfStream
'         wscript.echo ("filelist = " & InputFile.ReadLine)
' loop
' InputFile.Close


' Create a temporary file that will contain the set of files to be processed.
' This temporary file will have the same filenames as were passed in the input
' file list.  The difference is that the names will be quoted to accomodate 
' directory or file names that contains blanks.   
tempfilelist = filelist & ".quote"
Set OutputFile = fso.CreateTextFile(tempfilelist)
Set InputFile = fso.OpenTextFile(filelist, 1)
do while not InputFile.AtEndOfStream
   linefromfile = InputFile.Readline
   OutputFile.WriteLine ("""" & linefromfile & """") 
Loop
OutputFile.Close
InputFile.Close

' The following statements print the contents of the file that contains 
' the quoted file names.   This is the file list that will be passed to 
' ITSM.  These statements can be uncommented for information and 
' debugging purposes.
' Set InputFile = fso.OpenTextFile(tempfilelist, 1)
' do while not InputFile.AtEndOfStream
'         wscript.echo ("tempfilelist = " & InputFile.ReadLine)
' loop
' InputFile.Close


' Issue the command to archive files to ITSM and delete
const command = "%COMSPEC% /c "
Set cmdshell = WScript.CreateObject ("WScript.Shell")
set ObjscriptExec = cmdshell.exec (command & "SET PATH=%PATH%;C:\Program Files\Tivoli\TSM\baclient" _ 
                                   & "& SET DSM_DIR=" & dsm_dir _
                                   & "& SET DSM_CONFIG=" & dsm_config _
                                   & "& SET DSM_LOG=" & dsm_log _
                                   & "& dsmc archive -delete -subdir=no -filelist=" & tempfilelist & " 2>&1")


' Save the output of the ITSM command processing to the agent log.
set objStdOut = ObjscriptExec.stdout
do while not objstdout.AtEndOfStream
   wscript.echo (objstdout.ReadLine)
Loop


' Cleanup.
set cmdshell = Nothing
fso.DeleteFile(tempfilelist)