#! /bin/sh

#  ***************************************************************************
#  * IBM Confidential
#  *
#  * (C) Copyright IBM Corp. 2008, 2010
#  *
#  * 5608-VC3
#  *
#  * All Rights Reserved
#  *
#  * Licensed Material - Property of IBM
#  *
#  * The source code for this program is not published or otherwise
#  * divested of its trade secrets, irrespective of what has
#  * been deposited with the U. S. Copyright Office.
#  *
#   *******************************************************************

# HP-UX > 10 requires this
PATH=$PATH:/usr/sbin:/usr/bin:/sbin
export PATH

# Application
APP_NAME="StorageResourceAgent"
APP_LONG_NAME="Storage Resource Agent"
systemctl_param=$2
PRIORITY=

# Location of the pid file.
PIDDIR="../log"

OS=`/bin/uname`

MIN_RH_VER=7

# Do not modify anything beyond this point
#-----------------------------------------------------------------------------

# Get the fully qualified path to the script
case $0 in
    /*)
        SCRIPT="$0"
        ;;
    *)
        PWD=`pwd`
        SCRIPT="$PWD/$0"
        ;;
esac

# Change spaces to ":" so the tokens can be parsed.
SCRIPT=`echo $SCRIPT | sed -e 's; ;:;g'`
# Get the real path to this script, resolving any symbolic links
TOKENS=`echo $SCRIPT | sed -e 's;/; ;g'`
REALPATH=
for C in $TOKENS; do
    REALPATH="$REALPATH/$C"
    while [ -h "$REALPATH" ] ; do
        LS="`ls -ld "$REALPATH"`"
        LINK="`expr "$LS" : '.*-> \(.*\)$'`"
        if expr "$LINK" : '/.*' > /dev/null; then
            REALPATH="$LINK"
        else
            REALPATH="`dirname "$REALPATH"`""/$LINK"
        fi
    done
done
# Change ":" chars back to spaces.
REALPATH=`echo $REALPATH | sed -e 's;:; ;g'`

# Change the current directory to the location of the script
cd "`dirname "$REALPATH"`"

# Get Storage Resource Agent commands
AGENT_BIN=`dirname "$REALPATH"`

AGENT_CMD="`pwd`/Agent"
VERSION_CMD=""$AGENT_BIN"/Agent -version"

# Process ID
PIDFILE="$PIDDIR/agent.pid"
pid=""
TAILCMD=""

if [ -f /etc/redhat-release ]; then        		
	major_ver=`cat /etc/redhat-release | cut -d'.' -f1 | awk '{print $NF}'`	   	
   	if [ -f /etc/Tivoli/TSRM/registryNA ]; then			
		for line in `cat /etc/Tivoli/TSRM/registryNA`
		do
			if echo $line | grep -q Instance; then
				sra_instance=`echo ${line} | grep Instance | cut -d'=' -f2 | awk '{print $NF}'`
			else
				home=`echo ${line} |  cut -d'=' -f2 | awk '{print $NF}'`
				agent_bin_home=$home/agent/bin
				agent_script_location=`pwd`
   				if [ "$agent_bin_home" == "$agent_script_location" ]; then     
     				break
     			fi
			fi
		done			
   	fi
   	if [ -z $systemctl_param ] || [ $systemctl_param != "systemctl"  ]; then
		systemctl_passed=false
	else 
		systemctl_passed=true
	fi
fi

# Resolve the location of the 'ps' command
PSEXE="/usr/bin/ps"
if [ ! -x $PSEXE ]
then
    PSEXE="/bin/ps"
    if [ ! -x $PSEXE ]
    then
        echo "Unable to locate 'ps' in /bin."
        echo "Try updating this script with the correct location on your system."
        exit 1
    fi
fi

# Build the nice clause
if [ "X$PRIORITY" = "X" ]
then
    CMDNICE=""
else
    CMDNICE="nice -$PRIORITY"
fi

getpid() {
    getSupportedTail
    if [ -f $PIDFILE ]
    then
        if [ -r $PIDFILE ]
        then
            pid=`cat $PIDFILE`
            if [ "X$pid" != "X" ]
            then
                # Verify that a process with this pid is still running.
                pid=`$PSEXE -p $pid | grep $pid | grep -v grep | awk '{print $1}' | ${TAILCMD}`
            fi
        else
            echo "Cannot read $PIDFILE."
            exit 1
        fi
    fi
}


status() {
    echo "checking status of $APP_LONG_NAME..."
    getpid
    if [ "X$pid" = "X" ]
    then
	echo "$APP_LONG_NAME is not running."
	exit 1
    else
        echo "$APP_LONG_NAME is running."
        exit 0
    fi
}


getSupportedTail() {

    TAILCMD="tail -n 1"
    $TAILCMD ./agent.sh > /dev/null 2>&1

    if [ "$?" -ne 0 ]; then

            # Try the "older" syntax
            TAILCMD="tail -1"
            $TAILCMD ./agent.sh > /dev/null 2>&1

            if [ "$?" -ne 0 ]; then
                    echo "\"${TAILCMD}\" FAILED with return code $?"
            fi
    fi
}

testpid() {
    getSupportedTail
    pid=`$PSEXE -p $pid | grep $pid | grep -v grep | awk '{print $1}' | ${TAILCMD}`
}

start() {
    echo "Starting $APP_LONG_NAME..."
    if [ "$major_ver" -ge $MIN_RH_VER ] && [ $systemctl_passed == false ]; then	
    	sra_service=sra$sra_instance.service
		systemctl start $sra_service
	else    
   		getpid
    	if [ "X$pid" = "X" ]
    	then
        	exec nohup $CMDNICE "$AGENT_CMD" -daemon >/dev/null 2>&1 &
    	else
        	echo "$APP_LONG_NAME is already running."
        	exit 1
    	fi
    fi
}

stopit() {
    echo "Stopping $APP_LONG_NAME..."
    getpid
    if [ "X$pid" = "X" ]
    then
        echo "$APP_LONG_NAME was not running."
    else 
    # Running so try to stop it.
    	if [ "$major_ver" -ge $MIN_RH_VER ]; then	
    		sra_service=sra$sra_instance.service
			systemctl stop $sra_service
		else         
        	kill $pid
        	if [ $? -ne 0 ]
        	then
            # An explanation for the failure should have been given
            	echo "Unable to stop $APP_LONG_NAME."
            	exit 1
       		fi

        # We can not predict how long it will take for the nonstop to
        #  actually stop as it depends on settings
        #  Loop until it does.
        	savepid=$pid
        	CNT=0
        	TOTCNT=0
        	while [ "X$pid" != "X" ]
       		do
            # Loop for up to 5 minutes
            	if [ "$TOTCNT" -lt "300" ]
            	then
                	if [ "$CNT" -lt "5" ]
                	then
                    	CNT=`expr $CNT + 1`
                	else
                    	echo "Waiting for $APP_LONG_NAME to exit..."
                    	CNT=0
                	fi
                	TOTCNT=`expr $TOTCNT + 1`

                	sleep 1

                	testpid
            	else
                	pid=
           		fi
        	done

        	pid=$savepid
        	testpid
        	if [ "X$pid" != "X" ]
        	then
            	echo "Timed out waiting for $APP_LONG_NAME to exit."
            	echo "Please try again later, or consider a manual kill of the java process."
        	fi

        	pid=$savepid
        	testpid
        	if [ "X$pid" != "X" ]
        	then
            	echo "Failed to stop $APP_LONG_NAME."
            	exit 1
        	else
            	echo "Stopped $APP_LONG_NAME."
        	fi
    	fi
    fi
}

version()
{
   $VERSION_CMD
}

case "$1" in

    'start')
        start
        ;;

	'start_msg')
		echo "Starting $APP_LONG_NAME..."
		;;

    'stop')
        stopit
        ;;

	'stop_msg')
        echo "Stopping $APP_LONG_NAME..."
        ;;

    'restart')
        stopit
        start
        ;;

    'status')
        status
        ;;

    'version')
        version
        ;;

    'versionall')
        LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$AGENT_BIN
        export LD_LIBRARY_PATH
        echo "   Agent             : `$AGENT_BIN/Agent -version`"
        echo "   DbMonitor         : `$AGENT_BIN/DbMonitor -version`"
        echo "   Discovery         : `$AGENT_BIN/Discovery -version`"
        if [ $OS != "Linux" ]
        then
           echo "   FabricDiscovery   : `$AGENT_BIN/FabricDiscovery -version`"
           echo "   HBAInfo           : `$AGENT_BIN/HBAInfo -version`"
        fi
        echo "   NasFilerProbe     : `$AGENT_BIN/NasFilerProbe -version`"
        echo "   PathPlanner       : `$AGENT_BIN/PathPlanner -version`"
        echo "   Probe             : `$AGENT_BIN/Probe -version`"
        echo "   Scan              : `$AGENT_BIN/Scan -version`"
        echo "   SRAutil           : `$AGENT_BIN/SRAutil -version`"
        ;;

    *)
        echo "Usage:"
        echo "   $0 { status | start | stop | restart | version | versionall }"
        echo ""
        echo "Parameters explanation:"
        echo "   status     - return the current status of the Storage Resource Agent, either it is running or not"
        echo "   start      - start the Storage Resource Agent"
        echo "   stop       - stop the Storage Resource Agent"
        echo "   restart    - stop and then start the Storage Resource Agent"
        echo "   version    - display the current version of the Storage Resource Agent"
        echo "   versionall - display the versions of the Storage Resource Agent and its related components"
        echo ""
        exit 1
        ;;
esac

exit 0