#!/bin/sh

#   *******************************************************************
#   * Licensed Materials - Property of IBM
#   * Tivoli Common Agent
#   * BTC
#   * (C) Copyright IBM Corp. 2003, 2009. All Rights Reserved
#   *
#   * US Government Users Restricted Rights - Use, duplication or
#   * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#   *******************************************************************

cd "`dirname "$0"`"
GUID_IMAGE=`pwd`

OS=`uname -s`
result=0

echo "`date`: Starting GUID installation."

if [ "$OS" = "AIX" ]
then
	IMAGE_DIR=/tmp/guid.$$
	ln -s "${GUID_IMAGE}" ${IMAGE_DIR}

        installp -aX -d"${IMAGE_DIR}/aix4-r1" tivoli.tivguid
        result=$?

	rm ${IMAGE_DIR}

elif [ "$OS" = "SunOS" ]
then
        # pkgadd -n -a ./solaris2/guidadmin -d ./solaris2/TIVguid.pkg TIVguid
        ./installguid_sol.sh
        result=$?
elif [ "$OS" = "Linux" ]
then
    HW=`uname -m`
    case "$HW" in
      s390 | s390x)
            packagedVersion=`rpm -qp --qf '%{version}' ./linux-s390/TIVguid.s390.rpm`
            rpm -Uv ./linux-s390/TIVguid.s390.rpm
            result=$?
            ;;
      ppc*)
            packagedVersion=`rpm -qp --qf '%{version}' ./linux-ppc/TIVguid.ppc.rpm`
            rpm -Uv ./linux-ppc/TIVguid.ppc.rpm
            result=$?
            ;;
      *)
            packagedVersion=`rpm -qp --qf '%{version}' ./linux-ix86/TIVguid.i386.rpm`
            rpm -Uv ./linux-ix86/TIVguid.i386.rpm
            result=$?
            ;;
    esac

    # Set Linux GUID installation result
    if [ $result -ne "0" ]
    then
        installedVersion=`rpm -q --qf '%{version}' TIVguid`
        result=$?
        if [ $result -eq "0" ]
        then
            # GUID is installed
            # Set result to fail if version incorrect
            if [ "$installedVersion" != "$packagedVersion" ]
            then
              result=1
            fi
        fi
    fi
    
    # Refresh GUID shared library link following successful installation
    # Use this block of code to work around the fact that older versions
    # of RPM do not support '--nopreun' and '--nopostun'
    if [ $result -eq "0" ]
    then
        rm -f /usr/lib/libtivguid.so
        ln -s /opt/tivoli/guid/libtivguid.so /usr/lib/libtivguid.so    
    fi
elif [ "$OS" = "HP-UX" ]
then
        swinstall -x mount_all_filesystems=false -v -s "${GUID_IMAGE}"/hp-ux_itanium/TIVGUID TIVGUID
        result=$?

        if [ $result -eq "1" ]
        then
             swremove -x mount_all_filesystems=false -v TIVGUID
             swinstall -x mount_all_filesystems=false -v -s "${GUID_IMAGE}"/hp-ux_itanium/TIVGUID TIVGUID
             result=$?
        fi
else
        echo "`date`: GUID installation is not supported on platform ${OS}."
        exit 1
fi

if [ $result -ne "0" ]
then
    echo "`date`: GUID installation failed."
else
    echo "`date`: GUID installation succeeded."
fi

exit $result
