#!/bin/sh
#
# service.sh - IBM Spectrum Control Serviceability Tool Script

EC=0

#**************************************************
# Turn on debugging by uncommenting the line below
#**************************************************
#DEBUG_ARGS="-Djava.compiler=NONE -Xdebug -Xnoagent -Xrunjdwp:transport=dt_socket,server=y,suspend=y,address=7800"

#
# Cleanup function
#
Cleanup() {

if [ -f $SERVICE_DIR/hosts ]
then
rm $SERVICE_DIR/hosts
fi

if [ -f $SERVICE_DIR/version.txt ]
then
rm $SERVICE_DIR/version.txt
fi

if [ -f $SERVICE_DIR/license.txt ]
then
rm $SERVICE_DIR/license.txt
fi

if [ -f $SERVICE_DIR/msInfo.txt ]
then
rm $SERVICE_DIR/msInfo.txt
fi




return 0
}

#
# DataServer function
#
DataServer() {
DATA_SERVER_HOME=$pwd/../data
JAZZSM_HOME=
DE_HOME=
IA_INSTALL_LOG_DIR=
JAVA_PROPERTIES=
JVM_SETTINGS=-Xmx1024M

HOSTFile
VERSIONFile
LICENSEFile
PATCHFiles

PROGRAM_INSTALLED=$pwd/../../..
CLASSPATH=$pwd/../lib/TPC_Common.jar:$pwd/../lib/mail.jar:$pwd/../lib/ibmsdduu.jar:$pwd/../lib/soap.jar:$pwd/../lib/cu_runtime.jar
JAVAHOME=$pwd/../jre/bin
   
#echo " The data server class path is $CLASSPATH "
#echo " The data server java home is $JAVAHOME "

if [ -d $TPC_PROPERTY_DIR ] ; then
   if [ -f $TPC_PROPERTY_DIR/service.properties ] && [ -r $TPC_PROPERTY_DIR/service.properties ]
      then
      DATA_SERVER_HOME=`grep "DataServer" $TPC_PROPERTY_DIR/service.properties | cut -d'=' -f2`
      PROGRAM_INSTALLED=`printf "%s\n" "$DATA_SERVER_HOME" | cut -d'/' -f1,2`

      JAZZSM_HOME=`grep "JazzSM" $TPC_PROPERTY_DIR/service.properties | cut -d'=' -f2`

      DE_HOME="/usr/ibm/common/acsi"

      if [ $OS = "Linux" ]
         then
             IA_INSTALL_LOG_DIR="/root"
         else
             IA_INSTALL_LOG_DIR="/"
      fi

      JAVA_PROPERTIES="-DJAZZSM_HOME=$JAZZSM_HOME -DDE_HOME=$DE_HOME -DIA_INSTALL_LOG_DIR=$IA_INSTALL_LOG_DIR"
   fi
   
   if [ $DATA_SERVER_HOME="" ]
	then 
		DATA_SERVER_HOME=$pwd/../data
   fi
   if [ $PROGRAM_INSTALLED="" ]
	then
  	PROGRAM_INSTALLED=$pwd/../../..
   fi
   
   echo
   echo "Starting service program for IBM Spectrum Control with arg(s): $OPTIONS"
   sleep 5;

   $JAVAHOME/java $JVM_SETTINGS $JAVAARGS $JAVA_PROPERTIES $DEBUG_ARGS -cp $CLASSPATH com.tivoli.itsrm.tools.Service.Service $DATA_SERVER_HOME/service $PROGRAM_INSTALLED $OPTIONS
   EC=$?
   SERVICE="true"
   Cleanup     
fi

return 0
}

#
# HOSTFIle function
#
HOSTFile() {
HOST_FILE=
    
    if [ -f /etc/hosts ]
        then
        HOST_FILE='/etc/hosts'
    else
        echo Script can not find the host file on the system!
    fi
    cp $HOST_FILE $SERVICE_DIR

return 0
}

#
# VERSIONFile function
#
VERSIONFile() {
VERSION_FILE=
    
    if [ -f $TPC_PROPERTY_DIR/../version.txt ] && [ -r $TPC_PROPERTY_DIR/../version.txt ]
        then
        VERSION_FILE=$TPC_PROPERTY_DIR/../version.txt
    else
        echo Script can not find the version file on the system!
    fi
    cp $VERSION_FILE $SERVICE_DIR

return 0
}

#
# LICENSEFile function
#
LICENSEFile() {
    
    ls $TPC_PROPERTY_DIR/../properties/version/*.swtag 2>/dev/null | xargs -n1 basename > $SERVICE_DIR/license.txt 2>/dev/null
    if [ $? -ne 0 ]; then
        echo "**NO LICENSE FILE FOUND**" > $SERVICE_DIR/license.txt
    fi

return 0
}

#
# PatchFiles function
#
PATCHFiles() {
PATCH_VERSION_FILE=$TPC_PROPERTY_DIR/../patchVersion.txt
    if [ -f $PATCH_VERSION_FILE ] && [ -r $PATCH_VERSION_FILE ]
        then
        cp $PATCH_VERSION_FILE $SERVICE_DIR
    fi

PATCH_LOG_FILE=$TPC_PROPERTY_DIR/../patches/patchTool.log
    if [ -f $PATCH_LOG_FILE ] && [ -r $PATCH_LOG_FILE ]
        then
        cp $PATCH_LOG_FILE $SERVICE_DIR
    fi

return 0
}

#
# Main method if server components are installed
#
ServerMain() {

TPC_PROPERTY_DIR=
VPD_FILES_DIR=
CLASSPATH=
JAVAHOME=
UNIX_PLATFORM=
SERVER_HOST=
SERVICE="false"

OS=`/bin/uname -s`
cwd=`dirname $0`
cd $cwd 2> /dev/null
pwd=`pwd`

SERVICE_DIR=$pwd/.
JAVAARGS="-DTPC_SERVICE_DIR=$SERVICE_DIR"



timestamp=`date +"%s"`
filename=testprivileges$timestamp
touch $filename  2>/dev/null
if [ $? -gt 0 ]; then 
   echo "Run $0 with a user who has write permission in $SERVICE_DIR"
   exit 1 
fi
rm -rf $filename
#End verification

# Set the Data/Device server property file directory
TPC_PROPERTY_DIR="$pwd/../config"

   DataServer

   if [ "$SERVICE" = "false" ]; then
      echo
      echo "Collecting service information for IBM Spectrum Control products. Please wait..."
      sleep 5;
      echo "There are no server or agent logs to be collected"
   fi

   return 0
}

installLogs()
{
    if [ -d $pwd/../log/sra ]
    then
        cd $pwd/..
        INSTALL_FILES=`pwd`/log/sra
        cd $pwd/service
    fi
}

aixFabricMonitor()
{
	USRLIB=$pwd/service/Usrlibdir.txt
	ERRPT=$pwd/service/Errpt.txt
	HBAINFO=$pwd/service/HbaInfo.txt

	PLATFORM_FILES="$USRLIB,$ERRPT,$HBAINFO"
	DELETE_FILES="$USRLIB $ERRPT $HBAINFO"
	ls -l /usr/lib > $USRLIB
	errpt -a > $ERRPT 

	echo "HBA Driver and Firmware Info" > $HBAINFO 
	echo " " >> $HBAINFO
	for val in `lscfg | grep fcs | cut -d' ' -f2`
	do
		lscfg -vpl $val >> $HBAINFO
	done
	export DELETE_FILES
	export PLATFORM_FILES
}

linuxFabricMonitor()
{
	USRLIB=$pwd/service/UsrLibDir.txt
	HBAINFO=$pwd/service/HBAInfo.txt

	PLATFORM_FILES="$USRLIB,$HBAINFO"
	DELETE_FILES="$USRLIB $HBAINFO"
	ls -l /usr/lib > $USRLIB

	echo "HBA Driver and Firmware Info" > $HBAINFO 
	echo " " >> $HBAINFO
	for val in `lsmod | cut -d' ' -f1 | grep -i ql`
	do
		echo "$val :" >> $HBAINFO
		modinfo $val >> $HBAINFO
		echo " " >> $HBAINFO
	done
	export DELETE_FILES
	export PLATFORM_FILES
}

solarisFabricMonitor()
{
	USRLIB=$pwd/service/UsrLibDir.txt
	HBAINFO=$pwd/service/HBAInfo.txt

	PLATFORM_FILES="$USRLIB,$HBAINFO"
	DELETE_FILES="$USRLIB $HBAINFO"
	ls -l /usr/lib > $USRLIB

	echo "HBA Driver and Firmware Info" > $HBAINFO 

	echo " " >> $HBAINFO
	if test -f /usr/sbin/fcinfo
	then
		fcinfo hba-port >> $HBAINFO
		echo " " >> $HBAINFO
	fi

	for val in `pkginfo | grep -i qlogic | awk '{ print $2}'`
	do
		pkginfo -l  $val >> $HBAINFO
	done
	for val in `pkginfo | grep -i emulex | awk '{ print $2}'`
	do
		pkginfo -l  $val >> $HBAINFO
	done

	export DELETE_FILES
	export PLATFORM_FILES
}

#
#  function AgentArgumentError
#
AgentArgumentError() {

    echo "One or more of the options that were entered are invalid. See the help menu (option -help) for more information."
    return 0
}

#
#  function AgentHelp
#
AgentHelp() {

    echo "Usage: service [options]"
    echo "Option -all will be applied when no parameter is present"
    echo
    echo "Options:"
    echo "                -all          Collect service files for Storage Resource Agent"
    echo "                -sra          Collect service files for Storage Resource Agent"
    echo "                -help         Show usages"
    echo "                -nozip        Do not compress the service files"
    echo "                -output dir   Specify the output directory"
    echo    
    return 0
}

#
# Main method if only agent component is installed
#
AgentMain() {
OS=`/bin/uname`
cwd=`dirname $0`
cd $cwd
cd ..
pwd=`pwd`
cd service
hbainfo="true"

if [ "$OUTPUT_DIR" = "" ]; then
OUTPUT_DIR=$SERVICE_DIR/data
fi

if [ -d  "$OUTPUT_DIR" ]; then
echo
else
mkdir "$OUTPUT_DIR"
fi

echo "Service output directory = $OUTPUT_DIR"
echo "Collecting service information for IBM Spectrum Control..."
echo
echo "Collecting service information for component: sra"

IFCONFIG="ifconfig -a"
INSTALL_FILES=
PLATFORM_FILES=
DELETE_FILES=
PS_TXT=$pwd/service/Process.txt
ps -ef > $PS_TXT

case $OS in
	HP-UX)
		VPDDIR=/home/root/InstallShield/Universal/IBM-TPC/Gen1/_vpddb/vpd.script
		IFCONFIG="ifconfig lan0"
	;;
	AIX)
		VPDDIR=/usr/lib/objrepos/InstallShield/Universal/IBM-TPC/Gen1/_vpddb/vpd.script
		aixFabricMonitor
	;;
	Linux)
		arch=`uname -i`
		if test "$arch" != "i386"
		then 
        	hbainfo="false"
		fi
		VPDDIR=/root/InstallShield/Universal/IBM-TPC/Gen1/_vpddb/vpd.script
		linuxFabricMonitor
	;;
	SunOS)
		VPDDIR=/InstallShield/Universal/IBM-TPC/Gen1/_vpddb/vpd.script
		solarisFabricMonitor
	;;
esac

installLogs


CAPDIR=/opt/IBM/CAP
HTML=$pwd/service/IBMSpectrumControlServiceInfo.html
ZIPFILE=$OUTPUT_DIR/IBMSpectrumControlServiceInfo.zip
hostname=`hostname`

echo \<html\> > $HTML
echo \<head\>  >> $HTML
echo \<title\> >> $HTML
echo IBM Spectrum Control Service Program >> $HTML
echo \</title\> >> $HTML

echo \<script language=javascript\> >> $HTML
echo function showHideStuff \(whichSection\) >> $HTML
echo {  >> $HTML
echo 	sectObj = document.getElementById\(whichSection\)\; >> $HTML
echo	if \(sectObj.style.display == \"none\"\) {   >> $HTML
echo 		sectObj.style.display = \"block\"\;  >> $HTML
echo	} else {     >> $HTML
echo 		sectObj.style.display = \"none\"\;  >> $HTML
echo 	}   >> $HTML
echo }  >> $HTML
echo \</script\> >> $HTML

# ***************************************
#                OS Info
# ***************************************
echo \<b\> >> $HTML
echo IBM Spectrum Control Service Program>> $HTML
echo \</b\> >> $HTML
echo \</h1\>\</head\>\<body\>\<table\>\<pre\>>> $HTML
echo Date/Time is:  `date` >> $HTML
echo \</pre\> >> $HTML
echo \<pre\> >> $HTML
echo Collecting service information for IBM Spectrum Control products >> $HTML
echo \</pre\> >> $HTML
echo \<tr\> >> $HTML
echo \<td\>\<a href=\"javascript:showHideStuff\(\'section0\'\)\;\"\>+\</a\>\</td\> >> $HTML
echo \<td\>\<u\>\<b\>System Information\</b\>\</u\>\</td\> >> $HTML
echo \</tr\> >> $HTML
echo \<tr id=\"section0\" style=\"display:none\"\> >> $HTML
echo \<td width=\"5\"\>\&nbsp\; >> $HTML
echo \</td\>\<td\>\<table\>\<tr\>\<td\>\<pre\> >> $HTML
echo Host name is: `hostname` >> $HTML
echo OS Arch is: `uname -m` >> $HTML
echo OS Name is: `uname` >> $HTML 
echo OS Version is: `uname -a` >> $HTML
echo IBM Spectrum Control Product Install Dir is: $pwd >> $HTML
echo \</pre\>\</td\>\</tr\>\</table\>\</td\>\</tr\> >> $HTML
echo \<tr\>\<td\>\&nbsp\;\</td\>\</tr\> >> $HTML

# ***************************************
#           Executing OS Commands
# ***************************************
echo \<tr\> >> $HTML
echo \<td\>\<a href=\"javascript:showHideStuff\(\'section1\'\)\;\"\>+\</a\>\</td\> >> $HTML
echo \<td\>\<u\>\<b\>Executing OS/SRA Commands...\</b\>\</u\>\</td\> >> $HTML
echo \</tr\> >> $HTML
echo \<tr id=\"section1\" style=\"display:none\"\>  \<td width=\"5\"\>\&nbsp\;\</td\> \<td\>\<table\>\<tr\>\<td\>\<pre\> >> $HTML


# ***************************************
#           ifconfig
# ***************************************
echo \<tr\> >> $HTML
echo \<td\>\<a href=\"javascript:showHideStuff\(\'section2\'\)\;\"\>+\</a\>\</td\> >> $HTML
echo \<td\>\<u\>\<b\>ifconfig\</b\>\</u\>\</td\> >> $HTML
echo \</tr\> >> $HTML

echo \<tr id=\"section2\" style=\"display:none\"\>  \<td width=\"5\"\>\&nbsp\;\</td\> \<td\>\<table\>\<tr\>\<td\>\<pre\> >> $HTML
echo Cmd str to execute is -\>ifconfig\<- >> $HTML
$IFCONFIG >> $HTML
echo \</pre\>\</td\>\</tr\>\</table\>\</td\>\</tr\> >> $HTML
echo \<tr\>\<td\>\&nbsp\;\</td\>\</tr\> >> $HTML



# ***************************************
#             netstat -an
# ***************************************
echo \<tr\> >> $HTML
echo \<td\>\<a href=\"javascript:showHideStuff\(\'section3\'\)\;\"\>+\</a\>\</td\> >> $HTML
echo \<td\>\<u\>\<b\>netstat -an\</b\>\</u\>\</td\> >> $HTML
echo \</tr\> >> $HTML

echo \<tr id=\"section3\" style=\"display:none\"\>  \<td width=\"5\"\>\&nbsp\;\</td\> \<td\>\<table\>\<tr\>\<td\>\<pre\> >> $HTML
echo Cmd str to execute is -\>netstat -an\<- >> $HTML

netstat -an >> $HTML
echo \</pre\>\</td\>\</tr\>\</table\>\</td\>\</tr\> >> $HTML
echo \<tr\>\<td\>\&nbsp\;\</td\>\</tr\> >> $HTML

# ***************************************
#     dir c:\program files\ibm\tpc\agent
# ***************************************
echo \<tr\> >> $HTML
echo \<td\>\<a href=\"javascript:showHideStuff\(\'section4\'\)\;\"\>+\</a\>\</td\> >> $HTML
echo \<td\>\<u\>\<b\>ls -l %ROOTDIR%\</b\>\</u\>\</td\> >> $HTML
echo \</tr\> >> $HTML

echo \<tr id=\"section4\" style=\"display:none\"\>  \<td width=\"5\"\>\&nbsp\;\</td\> \<td\>\<table\>\<tr\>\<td\>\<pre\> >> $HTML
echo Cmd str to execute is -\>ls -l  $pwd\<- >> $HTML

ls -l $pwd >> $HTML
echo \</pre\>\</td\>\</tr\>\</table\>\</td\>\</tr\> >> $HTML
echo \<tr\>\<td\>\&nbsp\;\</td\>\</tr\> >> $HTML

# ***************************************
#  dir c:\program files\ibm\tpc\agent\bin
# ***************************************
echo \<tr\> >> $HTML
echo \<td\>\<a href=\"javascript:showHideStuff\(\'section5\'\)\;\"\>+\</a\>\</td\> >> $HTML
echo \<td\>\<u\>\<b\>ls -l %BINDIR%\</b\>\</u\>\</td\> >> $HTML
echo \</tr\> >> $HTML

echo \<tr id=\"section5\" style=\"display:none\"\>  \<td width=\"5\"\>\&nbsp\;\</td\> \<td\>\<table\>\<tr\>\<td\>\<pre\> >> $HTML
echo Cmd str to execute is -\>ls -l $pwd/bin \<- >> $HTML
ls -l $pwd/bin >> $HTML
echo \</pre\>\</td\>\</tr\>\</table\>\</td\>\</tr\> >> $HTML
echo \<tr\>\<td\>\&nbsp\;\</td\>\</tr\> >> $HTML

# ***************************************
#          agent.sh version
# ***************************************

LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$pwd/bin
export LD_LIBRARY_PATH
cd ..

echo \<tr\> >> $HTML
echo \<td\>\<a href=\"javascript:showHideStuff\(\'section6\'\)\;\"\>+\</a\>\</td\> >> $HTML
echo \<td\>\<u\>\<b\>Versions of SRA components\</b\>\</u\>\</td\> >> $HTML
echo \</tr\> >> $HTML

echo \<tr id=\"section6\" style=\"display:none\"\>  \<td width=\"5\"\>\&nbsp\;\</td\> \<td\>\<table\> >> $HTML

SRACOMP=Agent
echo \<tr\>\<td\>\<pre\> >> $HTML
echo Cmd str to execute is -\> $SRACOMP -version\<- >> $HTML
$pwd/bin/$SRACOMP -version >> $HTML
echo \</pre\>\</td\>\</tr\> >> $HTML

SRACOMP=DbMonitor
echo \<tr\>\<td\>\<pre\> >> $HTML
echo Cmd str to execute is -\> $SRACOMP -version\<- >> $HTML
$pwd/bin/$SRACOMP -version >> $HTML
echo \</pre\>\</td\>\</tr\> >> $HTML

SRACOMP=Discovery
echo \<tr\>\<td\>\<pre\> >> $HTML
echo Cmd str to execute is -\> $SRACOMP -version\<- >> $HTML
$pwd/bin/$SRACOMP -version >> $HTML
echo \</pre\>\</td\>\</tr\> >> $HTML

if test "$hbainfo" = "true"
then

	SRACOMP=FabricDiscovery
	echo \<tr\>\<td\>\<pre\> >> $HTML
	echo Cmd str to execute is -\> $SRACOMP -version\<- >> $HTML
	$pwd/bin/$SRACOMP -version >> $HTML
	echo \</pre\>\</td\>\</tr\> >> $HTML
	
	SRACOMP=FabricProbe
	echo \<tr\>\<td\>\<pre\> >> $HTML
	echo Cmd str to execute is -\> $SRACOMP -version\<- >> $HTML
	$pwd/bin/$SRACOMP -version >> $HTML
	echo \</pre\>\</td\>\</tr\> >> $HTML
	
	SRACOMP=FabricZoneControl
	echo \<tr\>\<td\>\<pre\> >> $HTML
	echo Cmd str to execute is -\> $SRACOMP -version\<- >> $HTML
	$pwd/bin/$SRACOMP -version >> $HTML
	echo \</pre\>\</td\>\</tr\> >> $HTML
	
	SRACOMP=HBAInfo
	echo \<tr\>\<td\>\<pre\> >> $HTML
	echo Cmd str to execute is -\> $SRACOMP -version\<- >> $HTML
	$pwd/bin/$SRACOMP -version >> $HTML
	echo \</pre\>\</td\>\</tr\> >> $HTML

fi

SRACOMP=NasFilerProbe
echo \<tr\>\<td\>\<pre\> >> $HTML
echo Cmd str to execute is -\> $SRACOMP -version\<- >> $HTML
$pwd/bin/$SRACOMP -version >> $HTML
echo \</pre\>\</td\>\</tr\> >> $HTML

SRACOMP=PathPlanner
echo \<tr\>\<td\>\<pre\> >> $HTML
echo Cmd str to execute is -\> $SRACOMP -version\<- >> $HTML
$pwd/bin/$SRACOMP -version >> $HTML
echo \</pre\>\</td\>\</tr\> >> $HTML

SRACOMP=Probe
echo \<tr\>\<td\>\<pre\> >> $HTML
echo Cmd str to execute is -\> $SRACOMP -version\<- >> $HTML
$pwd/bin/$SRACOMP -version >> $HTML
echo \</pre\>\</td\>\</tr\> >> $HTML

SRACOMP=Scan
echo \<tr\>\<td\>\<pre\> >> $HTML
echo Cmd str to execute is -\> $SRACOMP -version\<- >> $HTML
$pwd/bin/$SRACOMP -version >> $HTML
echo \</pre\>\</td\>\</tr\> >> $HTML

SRACOMP=SRAutil
echo \<tr\>\<td\>\<pre\> >> $HTML
echo Cmd str to execute is -\> $SRACOMP -version\<- >> $HTML
$pwd/bin/$SRACOMP -version >> $HTML
echo \</pre\>\</td\>\</tr\> >> $HTML

SRACOMP=

echo \</table\>\</td\>\</tr\> >> $HTML
echo \<tr\>\<td\>\&nbsp\;\</td\>\</tr\> >> $HTML


# ***************************************
#           df -k
# ***************************************
echo \<tr\> >> $HTML
echo \<td\>\<a href=\"javascript:showHideStuff\(\'section7\'\)\;\"\>+\</a\>\</td\> >> $HTML
echo \<td\>\<u\>\<b\>df -k\</b\>\</u\>\</td\> >> $HTML
echo \</tr\> >> $HTML

echo \<tr id=\"section7\" style=\"display:none\"\>  \<td width=\"5\"\>\&nbsp\;\</td\> \<td\>\<table\>\<tr\>\<td\>\<pre\> >> $HTML
echo Cmd str to execute is -\>df -k\<- >> $HTML
df -k >> $HTML
echo \</pre\>\</td\>\</tr\>\</table\>\</td\>\</tr\> >> $HTML
echo \<tr\>\<td\>\&nbsp\;\</td\>\</tr\> >> $HTML


echo \</pre\>\</td\>\</tr\>\</table\>\</td\>\</tr\> >> $HTML
echo \<tr\>\<td\>\&nbsp\;\</td\>\</tr\> >> $HTML

echo \</table\> >> $HTML
echo \</body\> >> $HTML
echo \</html\> >> $HTML

echo "Service completed successfully for Component: sra"
echo "Service information was collected in $OUTPUT_DIR"

# ****************************************
#        Create service zip file
# ****************************************
if [ "$NOZIP_SELECTED" = "" ]; then
eval $pwd/bin/Agent -zip -name $ZIPFILE -files $PS_TXT,$PLATFORM_FILES,$CAPDIR,$VPDDIR,$HTML,version.txt,config,log,output,nls,/etc/hba.conf,/var/log/messages,/proc/scsi,$INSTALL_FILES -force
else
if [ -d "$OUTPUT_DIR/sra" ]; then
rmdir "$OUTPUT_DIR/sra"
fi

mkdir "$OUTPUT_DIR/sra"

mkdir "$OUTPUT_DIR/sra/service"
mkdir "$OUTPUT_DIR/sra/installfiles"
mkdir "$OUTPUT_DIR/sra/var"
mkdir "$OUTPUT_DIR/sra/etc"
	
if [ -f "$pwd/service/Usrlibdir.txt" ]; then
cp  $pwd/service/Usrlibdir.txt "$OUTPUT_DIR/sra/service"
fi

if [ -f "$pwd/service/Errpt.txt" ]; then
cp  $pwd/service/Errpt.txt "$OUTPUT_DIR/sra/service"
fi

if [ -f "$pwd/service/HbaInfo.txt" ]; then
cp  $pwd/service/HbaInfo.txt "$OUTPUT_DIR/sra/service"
fi

if [ -f "$PS_TXT" ]; then
cp  $PS_TXT "$OUTPUT_DIR/sra/service"
fi

if [ -d $CAPDIR ]; then
cp -r $CAPDIR "$OUTPUT_DIR/sra"
fi

if [ -f $VPDDIR ]; then
cp $VPDDIR "$OUTPUT_DIR/sra/service"
fi

if [ -f $HTML ]; then
cp $HTML "$OUTPUT_DIR/sra/service"
fi

if [ -f "$pwd/version.txt" ]; then
cp  $pwd/version.txt "$OUTPUT_DIR/sra"
fi

if [ -d $SERVICE_DIR/../config ]; then
cp -r $SERVICE_DIR/../config "$OUTPUT_DIR/sra"
fi

if [ -d $SERVICE_DIR/../log ]; then
cp -r $SERVICE_DIR/../log "$OUTPUT_DIR/sra"
fi

if [ -d $SERVICE_DIR/../output ]; then
cp -r $SERVICE_DIR/../output "$OUTPUT_DIR/sra"
fi

if [ -d $SERVICE_DIR/../nls ]; then
cp -r $SERVICE_DIR/../nls "$OUTPUT_DIR/sra"
fi

if [ -f "/etc/hba.conf" ]; then
cp  /etc/hba.conf "$OUTPUT_DIR/sra/etc"
fi

if [ -f "/var/log/messages" ]; then
cp  /var/log/messages "$OUTPUT_DIR/sra/var"
fi 

if [ -d /proc/scsi ]; then
cp  -r /proc/scsi "$OUTPUT_DIR/sra"
fi

if [ -d "$INSTALL_FILES" ]; then
cp  -r "$INSTALL_FILES" "$OUTPUT_DIR/sra/installfiles"
fi 
 
fi
rm -fr $HTML $DELETE_FILES $PS_TXT
echo "Service completed successfully. Exiting Service Tool"
echo "Send the service file to IBM for diagnostic evaluation" 

   return 0
}

# main part of the script

cd `dirname $0`
pwd=`pwd`
SERVICE_DIR=$pwd

OPTIONS=""

HELP_SELECTED=
ALL_SELECTED=
NOZIP_SELECTED=
OUTPUT_SELECTED=
FILENAME_SELECTED=
SRA_SELECTED=
OUTPUT_DIR=
FILENAME=
INVALID_ARGUMENT=
OUTPUT_DIR_SET_IN_LOOP=
FILENAME_SET_IN_LOOP=

#capture args passed into the script
#echo "script numOfparams: $#; string of params: $*"
if [ $# -eq 0 ]; then
    OPTIONS="-all"
else
    OPTIONS=$*
    if [ `expr "$OPTIONS" : ".*-dump.*"` -ne 0 ]; then
        OPT1=`expr "$OPTIONS" : "\(.*\)-dump.*"`
        OPT2=`expr "$OPTIONS" : ".*-dump\(.*\)"`
        OPTIONS="$OPT1$OPT2"
        if [ -z "$OPTIONS" ]; then OPTIONS="-all"; fi
    fi

fi

while [ $# -gt 0 ] ; do
OUTPUT_DIR_SET_IN_LOOP=
if [ "$OUTPUT_SELECTED" = "true" ]; then 
OUTPUT_DIR=$1
OUTPUT_SELECTED=
OUTPUT_DIR_SET_IN_LOOP=true
fi


FILENAME_SET_IN_LOOP=
if [ "$FILENAME_SELECTED" = "true" ]; then 
FILENAME=$1
FILENAME_SELECTED=
FILENAME_SET_IN_LOOP=true
fi

if [ $1 = "-help" ]; then 
HELP_SELECTED=true
elif [ $1 = "-all" ]; then 
ALL_SELECTED=true
elif [ $1 = "-nozip" ]; then 
NOZIP_SELECTED=true 
elif [ $1 = "-output" ]; then 
OUTPUT_SELECTED=true
elif [ $1 = "-filename" ]; then 
FILENAME_SELECTED=true
elif [ $1 = "-sra" ]; then 
SRA_SELECTED=true
elif [ $1 = "-dump" ]; then 
DUMP_SELECTED=true
fi

if [ "$FILENAME_SET_IN_LOOP" != "true" ] && [ "$OUTPUT_DIR_SET_IN_LOOP" != "true" ] && [ "$HELP_SELECTED" != "true" ] && [ "$ALL_SELECTED" != "true" ] && [ "$NOZIP_SELECTED" != "true" ] && [ "$OUTPUT_SELECTED" != "true" ] && [ "$SRA_SELECTED" != "true" ]; then 
INVALID_ARGUMENT=true
fi

if [ "$INVALID_ARGUMENT" = "true" ]; then 
break
fi      
     
shift
    
done


if [ -f "../_uninst/.tpcreg" ]; then 
ServerMain
else
echo
echo "Starting service program for IBM Spectrum Control with arg(s): $OPTIONS"
echo
echo "IBM Spectrum Control Service Program"
echo
echo $SERVICE_DIR
echo "Service directory = $SERVICE_DIR"
echo
if [ "$INVALID_ARGUMENT" = "" ]; then
if [ "$HELP_SELECTED" = "true" ]; then
AgentHelp
else    
AgentMain
fi
else
AgentArgumentError                     
fi
fi                     

if [ ! -z "$DUMP_SELECTED" ]; then
    echo ""
    echo "Generating server dumps and db2 snapshots. This will take between 10 and 20 minutes."
    echo "The server dumps and db2 snapshots will be put in dump/IBMSpectrumControlServiceDump.zip."
    $pwd/dump.sh
fi

exit $EC
